@@ -8,6 +8,7 @@ import os
 import tempfile
 import logging
 from utf_queue_client import DISABLE_SSL_VERIFICATION_DEFAULT
+import urllib3
 
 telemetry_initialized = False
 
@@ -63,6 +64,7 @@ def setup_telemetry():
             == "true"
         ):
             os.environ["OTEL_EXPORTER_OTLP_CERTIFICATE"] = ""
+            urllib3.disable_warnings()
         options = TelemetryOptions(
             OTEL_SERVICE_NAME=SERVICE_NAME,
             OTEL_EXPORTER_OTLP_ENDPOINT=os.environ.get(
